@@ -44,8 +44,11 @@ See the online user guide for more information.
 
 __docformat__ = 'reStructuredText'
 
+from .aopexception import AOPException
 from .advisor import advisor
-from .commands import (proceed, return_, arguments, advised, obj, name)
+from .commands import (
+    proceed, return_, arguments, advised_attribute, advised_instance, suppress_aspect
+)
 from .aopmeta import AOPMeta
 from .aspect import Aspect
 
