@@ -26,11 +26,13 @@ def _wrapped_call(obj, name, f, args, kwargs):
 
     This allows for support of bound methods, ...
     '''
+    original_f = f
     # f: the originally returned func
     if hasattr(f, '__self__'): # bound beastie?
         # unbind
         args = (f.__self__,) + args
         f = f.__func__ # get the original func and use that instead
 
-    return advisor.process_call(obj, name, f, '__call__', args, kwargs)
+    return advisor.process_call(obj, name, f, 'call', args, kwargs,
+                                original_f)
 
