@@ -19,48 +19,12 @@
 __docformat__ = 'reStructuredText'
 
 import copy
+from functools import reduce
 
 class Profile(object):
 
     """
     States what attributes to delegate, and to which target attributes.
-
-    Instance methods:
-        
-        - `has_readable`: Check for read-access mapping of attribute
-        - `has_writable`: Check for read-access mapping of attribute
-        - `has_deletable`: Check for read-access mapping of attribute
-        - `get_readable`: Get read-access mapping for attribute
-        - `get_writable`: Get read-access mapping for attribute
-        - `get_deletable`: Get read-access mapping for attribute
-        - `remove_mappings`: Remove attribute mappings
-        - `add_mappings`: Add attribute mappings
-
-    Operators:
-
-        self |= b::Profile
-            union of this profile and the other
-
-        self | b::Profile
-            union of this profile and the other
-
-        self &= b::Profile
-            intersection of this profile and the other
-
-        self & b::Profile
-            intersection of this profile and the other
-
-        self - b::Profile
-            difference of this profile and the other
-
-        self -= b::Profile
-            difference of this profile and the other
-
-        self ^ b::Profile
-            symetric difference of this profile and the other
-
-        self ^= b::Profile
-            symetric difference of this profile and the other
     """
 
     def __init__(self):
@@ -72,7 +36,7 @@ class Profile(object):
         """
         Check for read-access mapping of attribute
 
-        Returns True if the mapping exists
+        :return: True if the mapping exists
         """
         return attribute in self.__readables
 
@@ -80,7 +44,7 @@ class Profile(object):
         """
         Check for write-access mapping of attribute
 
-        Returns True if the mapping exists
+        :return: True if the mapping exists
         """
         return attribute in self.__writables
 
@@ -88,7 +52,7 @@ class Profile(object):
         """
         Check for delete-access mapping of attribute
 
-        Returns True if the mapping exists
+        :return: True if the mapping exists
         """
         return attribute in self.__deletables
 
@@ -96,7 +60,7 @@ class Profile(object):
         """
         Get the mapped value of a readable attribute
 
-        Returns ::string
+        :rtype: string
         """
         return self.__readables[attribute]
 
@@ -104,7 +68,7 @@ class Profile(object):
         """
         Get the mapped value of a writable attribute
 
-        Returns ::string
+        :rtype: string
         """
         return self.__writables[attribute]
 
@@ -112,13 +76,13 @@ class Profile(object):
         """
         Get the mapped value of a deletable attribute
 
-        Returns ::string
+        :rtype: string
         """
         return self.__deletables[attribute]
 
     def __are_conflict_free(self, other):
         '''
-        Returns True if mappings of self don't conflict with those of other
+        :return: True if mappings of self don't conflict with those of other
         '''
         # check for conflicts: intersect keys, then see whether intersections
         # map to the same values
@@ -130,7 +94,7 @@ class Profile(object):
                       (reduce(lambda x,y: x and y,
                               (a[key] == b[key]
                               for key 
-                              in set(a.iterkeys()) & set(b.iterkeys())),
+                              in set(a) & set(b)),
                               True)
                       for a, b
                       in zip((self.__readables, self.__writables,
@@ -150,15 +114,12 @@ class Profile(object):
         """
         union of this profile and the other
 
-        Parameters:
+        :param other: the other profile
+        :type other: Profile
 
-            - `other` :: Profile
-                the other profile
-
-        Preconditions:
-            1. The mappings of the two profiles musn't conflict. Two profiles
-            conflict when they have at least one mapping with the same source
-            name, but a different target name.
+        :Preconditions: 1. The mappings of the two profiles musn't conflict. Two profiles
+           conflict when they have at least one mapping with the same source
+           name, but a different target name.
         """
         assert self.__are_conflict_free(other), \
             "Profiles have conflicting mappings, can't take union"
@@ -178,13 +139,10 @@ class Profile(object):
         """
         intersection of this profile and the other
 
-        Parameters:
+        :param other: the other profile
+        :type other: Profile
 
-            - `other` :: Profile
-                the other profile
-
-        Preconditions:
-            1. The mappings of the two profiles musn't conflict. Two profiles
+        :Preconditions: 1. The mappings of the two profiles musn't conflict. Two profiles
             conflict when they have at least one mapping with the same source
             name, but a different target name.
         """
@@ -196,7 +154,7 @@ class Profile(object):
         for a, b in zip(
             (self.__readables, self.__writables, self.__deletables),
             (other.__readables, other.__writables, other.__deletables)):
-            for key in a.keys():
+            for key in tuple(a.keys()):
                 if key not in b:
                     del a[key]
 
@@ -212,16 +170,14 @@ class Profile(object):
         """
         difference of this profile and the other
 
-        Parameters:
-
-            - `other` :: Profile
-                the other profile
+        :param other: the other profile
+        :type other: Profile
         """
 
         for a, b in zip(
             (self.__readables, self.__writables, self.__deletables),
             (other.__readables, other.__writables, other.__deletables)):
-            for key in a.keys():
+            for key in tuple(a.keys()):
                 if key in b:
                     del a[key]
 
@@ -237,19 +193,17 @@ class Profile(object):
         """
         symetric difference of this profile and the other
 
-        Parameters:
-
-            - `other` :: Profile
-                the other profile
+        :param other: the other profile
+        :type other: Profile
         """
         
         # get the intersection of keys
-        inter_readables = set(self.__readables.iterkeys()) \
-                         & set(other.__readables.iterkeys())
-        inter_writables = set(self.__writables.iterkeys()) \
-                         & set(other.__writables.iterkeys())
-        inter_deletables = set(self.__deletables.iterkeys()) \
-                         & set(other.__deletables.iterkeys())
+        inter_readables = set(self.__readables.keys()) \
+                         & set(other.__readables.keys())
+        inter_writables = set(self.__writables.keys()) \
+                         & set(other.__writables.keys())
+        inter_deletables = set(self.__deletables.keys()) \
+                         & set(other.__deletables.keys())
 
         # or the two together
         self.__readables.update(other.__readables)
@@ -260,7 +214,7 @@ class Profile(object):
         for a, b in zip(
             (self.__readables, self.__writables, self.__deletables),
             (inter_readables, inter_writables, inter_deletables)):
-            for key in a.keys():
+            for key in tuple(a.keys()):
                 if key in b:
                     del a[key]
 
@@ -270,22 +224,21 @@ class Profile(object):
         """
         Remove attribute mappings
         
-        Parameters:
+        :param modifiers: 
+            the types of delegation access to the target. Valid modifiers
+            are combinations of:
+                
+            - 'r': read
+            - 'w': write
+            - 'd': delete
+        :type modifiers: string
 
-            `modifiers` :: string
-                the types of delegation access to the target to remove. Valid 
-                modifiers are combinations of:
-                    
-                    - `r`: read
-                    - `w`: write
-                    - `d`: delete
-
-            `names` :: (source_name::string...)
-                names of source_name parts of, the mappings to remove
+        :param names: source names of the attribute names to remove
+        :type names: (string...)
         """
 
         for name in names:
-            assert isinstance(name, basestring), \
+            assert isinstance(name, str), \
                     "Invalid arguments: names should be list of strings: %s" \
                     % (names)
 
@@ -304,37 +257,36 @@ class Profile(object):
         """
         Map source to target attribute names, for delegation.
         
-        Parameters:
+        :param modifiers: 
+            the types of delegation access to the target. Valid modifiers
+            are combinations of:
+                
+            - 'r': read
+            - 'w': write
+            - 'd': delete
+        :type modifiers: string
 
-            `modifiers` :: string
-                the types of delegation access to the target. Valid modifiers
-                are combinations of:
-                    
-                    - `r`: read
-                    - `w`: write
-                    - `d`: delete
+        :param names: source names of the attribute names to delegate. The target attribute
+            name is the same as `source_name`. This is the same as adding a
+            {source_name : source_name} mapping, using the mapped_names
+            argument.
+        :type names: (string...)
 
-            `names` :: (source_name::string...)
-                names of the attribute names to delegate. The target attribute
-                name is the same as `source_name`. This is the same as adding a
-                {source_name : source_name} mapping, using the mapped_names
-                argument.
+        :param mapped_names: names of source and target attributes to map and delegate.
 
-            `mapped_names` :: {source_name::string : target_name::string ...}
-                names of source and target attributes to map and delegate.
-
-                `target_name`s will be mangled if they have a __ prefix.
-                Mangling will occur every time it is delegated to, so you can
-                change the target object any time.
+            target_name will be mangled if they have a __ prefix.
+            Mangling will occur every time it is delegated to, so you can
+            change the target object any time.
+        :type mapped_names: {source_name of string : target_name of string}
         """
         for name in names:
-            assert isinstance(name, basestring), (
+            assert isinstance(name, str), (
                 "Invalid arguments: names should be list of strings. Got: %s" %
                 names)
 
-        for key, name in mapped_names.iteritems():
-            assert isinstance(key, basestring) and \
-                    isinstance(name, basestring), \
+        for key, name in mapped_names.items():
+            assert isinstance(key, str) and \
+                    isinstance(name, str), \
                     "Invalid arguments: mapped_names should be dict of " + \
                     "string:string. Got: %s" % mapped_names
 
@@ -350,4 +302,48 @@ class Profile(object):
     def copy(self):
         return copy.deepcopy(self)
 
+    @property
+    def readables(self):
+        '''
+        Get all readable attributes
+
+        :return: (attribute_name, ...)
+        :rtype: iter(str, ...)
+        '''
+        return self.__readables.keys()
+
+    @property
+    def writables(self):
+        '''
+        Get all writables attributes
+
+        :return: (attribute_name, ...)
+        :rtype: iter(str, ...)
+        '''
+        return self.__writables.keys()
+
+    @property
+    def deletables(self):
+        '''
+        Get all deletables attributes
+
+        :return: (attribute_name, ...)
+        :rtype: iter(str, ...)
+        '''
+        return self.__deletables.keys()
+
+    @property
+    def attributes(self):
+        '''
+        Get all attributes, no matter what access they provide
+
+        :return: (attribute_name, ...)
+        :rtype: iter(str, ...)
+        '''
+        return self.readables + self.writables + self.deletables
+
+    def __str__(self):
+        return 'Profile: r: %s, w: %s, d: %s' % (self.__readables,
+                                                 self.__writables,
+                                                 self.__deletables)
 
