@@ -24,6 +24,7 @@ import pdb
 from pytilities.descriptors import BoundDescriptor
 from pytilities.geometry import (
     DiscreteVector, Vector, ImmutableVector, verbose_vector_aspect)
+from pytilities.aop.aspects import ImmutableAttributeException
 
 class VectorTestCase(TestCase):
     def setUp(self):
@@ -186,44 +187,44 @@ class ImmutableVectorTestCase(VectorTestCase):
         self.p = ImmutableVector(self.p)
 
     def test_set_x(self):
-        self.assertRaises(AssertionError,
-                          VectorTestCase.test_set_x, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_set_x(self)
 
     def test_set_y(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_set_y, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_set_y(self)
 
     def test_move_to(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_move_to, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_move_to(self)
 
     def test_move_by(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_move_by, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_move_by(self)
         
     def test_iadd(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_iadd, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_iadd(self)
 
     def test_isub(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_isub, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_isub(self)
 
     def test_imul(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_imul, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_imul(self)
 
     def test_itruediv(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_itruediv, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_itruediv(self)
 
     def test_ifloordiv(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_ifloordiv, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_ifloordiv(self)
 
     def test_assign(self):
-        self.assertRaises(AssertionError, 
-                          VectorTestCase.test_assign, self)
+        with self.assertRaises(ImmutableAttributeException):
+            VectorTestCase.test_assign(self)
 
 class VerboseHelper(object):
     def __init__(self, v):
