@@ -21,18 +21,12 @@ Various types
 
 Classes:
 
-    - `NumericType`: Represents any numeric type.
-    - `NumberType`: Represents any number type.
-    - `SequenceType`: Represents any ordered sequence.
-    - all types from the standard types package
+- `NumericType`: Represents any numeric type.
+- `NumberType`: Represents any number type.
+- `SequenceType`: Represents any ordered sequence.
+- all types from the standard types package
 """
 
-# Normally from name, looks for .name first, in order to change this behaviour
-# to just look for the absolute name we first import absolut_import from the
-# future
-from __future__ import absolute_import as _absolute_import
-
-# now we can get types, rather than .types :/
 from types import *
 
 # custom types
